@@ -126,6 +126,10 @@ module.exports = function (app) {
                         { name: '.' },
                     ],
                 }));
+                app.nylon.res.tmp_dir='./public/build/'+evn_build+'/tmp/';
+
+               
+
             }else{
                 app.get('/*', prpl.makeHandler('./public', {
                     builds: [
@@ -133,8 +137,14 @@ module.exports = function (app) {
                         { name: '.' },
                     ],
                 }));
+                app.nylon.res.tmp_dir='./public/tmp/';
+
             }
-            
+
+            if (!fs.existsSync(app.nylon.res.tmp_dir)) {
+                fs.mkdirSync(app.nylon.res.tmp_dir, 0744);
+            }
+          
 
         });
     });
